ZArithmeticMeanRank
===================

.. currentmodule:: pykeen.metrics.ranking

.. autoclass:: ZArithmeticMeanRank
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~ZArithmeticMeanRank.name
      ~ZArithmeticMeanRank.synonyms

   .. rubric:: Attributes Documentation

   .. autoattribute:: name
   .. autoattribute:: synonyms
